.. _bibliography:

Bibliography
============

.. [Baeriswyl2022]  
   \ C. Baeriswyl, A. Bertrand, and R. A. Wildhaber, "Windowed State Space Filters for Peak Interference Suppression in Neural Spike Sorting", 30th European Signal Processing Conference (EUSIPCO 2022), Belgrad, Spain. (accepted) 
   

.. [Waldmann2022]
   \ F. Waldmann, Ch. Baeriswyl, R. Andonie, R. Wildhaber, "Onset Detection of Pulse-Shaped Bioelectrical Signals Using Linear State Space Models", (accepted for BMT2022, Austria)


.. [Wildhaber2020]
   \ R. A. wildhaber, E. Ren, F. Waldmann, and H.-A. Loeliger, "Signal Analysis Using Local Polynomial Approximations," EUSIPCO 2020

.. [Wildhaber2018]
   \ R. A. Wildhaber, N. Zalmai, M. Jacomet, and H.-A. Loeliger, "Windowed statespace filters for signal detection and separation," IEEE Transactions on Signal Processing, vol. 66, no. 14, pp. 3768–3783, 2018, issn: 1053-587X. doi: 10.1109/TSP.2018.2833804. [Online]. Available: https://ieeexplore.ieee.org/document/8355586

.. [Wildhaber2019]
   \ R. A. Wildhaber, "Localized State Space and Polynomial Filters with Applications in Electrocardiography", Hartung-Gorre-Verlag Konstanz, issn: 1616-671X, 2019. [Online]
   Available: https://www.research-collection.ethz.ch/bitstream/handle/20.500.11850/357916/thesis-book-final.pdf?sequence=1&isAllowed=y

.. [Zalmai2017]
   \ N. Zalmai, "A State Space World for Detecting and Estimating Events and Learning Sparse Signal Decompositions", Hartung-Gorre-Verlag Konstanz, issn: 1616-671X, 2017. [Online]
   Available: https://www.research-collection.ethz.ch/bitstream/handle/20.500.11850/176652/zalmai_thesis.pdf?sequence=1&isAllowed=y

.. [Loeliger2016]
   \ H.-A. Loeliger, L. Bruderer, H. Malmberg, F. Wadehn, and N. Zalmai, "On Sparsity by NUV-EM, Gaussian Message Passing, and Kalman Smoothing", CoRR, vol. abs/1602.02673, 2016. arXiv: 1602 . 02673. [Online]. Available: http://arxiv.org/abs/1602.02673.

